#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
from pathlib import Path

from tqdm import tqdm

from .interfaces import FetchProgressReporter


class ProgressNonReporter(FetchProgressReporter):
    """
    Reports no progress as files complete. Useful as a default and for testing.
    """

    def complete(self, path: Path):
        """Does nothing with the fact that some files are complete."""


class ProgressBarReporter(FetchProgressReporter):
    """
    Display progress bar as the files are fetched.
    """

    def __init__(self, total):
        self.progress = tqdm(total=total, unit="byte", unit_scale=True, unit_divisor=1024)

    def complete(self, path: Path):
        self.progress.update(path.stat().st_size)
