# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""State machine templating system init

Revision ID: eda4094d32bd
Revises: baf4d187d454
Create Date: 2022-01-13 15:39:55.803368

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "eda4094d32bd"
down_revision = "baf4d187d454"
branch_labels = None
depends_on = None


def upgrade():
    create_state_machine_table_sql = """
    CREATE TABLE IF NOT EXISTS capability_state_machines (
      capability_name VARCHAR PRIMARY KEY REFERENCES capabilities ON UPDATE CASCADE ON DELETE CASCADE,
      machine_type VARCHAR NOT NULL,
      associated_workflows JSON
    );
    """
    op.execute(create_state_machine_table_sql)

    state_machine_inserts_sql = """
    INSERT INTO capability_state_machines (capability_name, machine_type, associated_workflows)
    VALUES ('null', 'simple', '{"workflow_name": "null"}');

    INSERT INTO capability_state_machines (capability_name, machine_type, associated_workflows)
    VALUES ('null_dag', 'simple', '{"workflow_name": "null_dag"}');

    INSERT INTO capability_state_machines (capability_name, machine_type, associated_workflows)
    VALUES ('test_download', 'simple', '{"workflow_name": "test_download"}');

    INSERT INTO capability_state_machines (capability_name, machine_type, associated_workflows)
    VALUES ('restore_cms', 'simple', '{"workflow_name": "restore_cms"}');

    INSERT INTO capability_state_machines (capability_name, machine_type, associated_workflows)
    VALUES ('std_cms_imaging', 'simple', '{"workflow_name": "std_cms_imaging"}');

    INSERT INTO capability_state_machines (capability_name, machine_type, associated_workflows)
    VALUES ('std_restore_imaging', 'simple', '{"workflow_name": "std_restore_imaging"}');

    INSERT INTO capability_state_machines (capability_name, machine_type, associated_workflows)
    VALUES ('std_calibration', 'single_qa', '{"workflow_name": "std_calibration", "qa_pass_workflow_name": "ingest_cal", "qa_fail_workflow_name": "qa_fail"}');
    """
    op.execute(state_machine_inserts_sql)


def downgrade():
    drop_state_machine_table_sql = """
    DROP TABLE capability_state_machines;
    """
    op.execute(drop_state_machine_table_sql)
